@@ -117,16 +117,16 @@ class PythonSpadeCode(PythonCode):
         self.indent_left()
         
     def add_agent_constructor(self, agent: Agent) -> None:
-        self.add_line('def __init__(self, jid, password, connections, backup_url = None, backup_period = 60, backup_delay = 0, logger = None, **kwargs):')
+        self.add_line('def __init__(self, jid, password, backup_url = None, backup_period = 60, backup_delay = 0, logger = None, **kwargs):')
         self.indent_right()
 
         self.add_line('super().__init__(jid, password, verify_security=False)')
-        self.add_line('if logger: logger.debug(f"[{jid}] Received parameters: jid: {jid}, password: {password}, connections: {connections}, backup_url: {backup_url}, backup_period: {backup_period}, backup_delay: {backup_delay}, kwargs: {kwargs}")')
+        self.add_line('if logger: logger.debug(f"[{jid}] Received parameters: jid: {jid}, password: {password}, backup_url: {backup_url}, backup_period: {backup_period}, backup_delay: {backup_delay}, kwargs: {kwargs}")')
         self.add_line('self.logger = logger')
-        self.add_line('self.connections = connections')
         self.add_line('self.backup_url = backup_url')
         self.add_line('self.backup_period = backup_period')
         self.add_line('self.backup_delay = backup_delay')
+        self.add_line('self.connections = kwargs.get("connections", [])')
         self.add_line('self.msgRCount = kwargs.get("msgRCount", 0)')
         self.add_line('self.msgSCount = kwargs.get("msgSCount", 0)')
 
@@ -224,26 +224,62 @@ class PythonSpadeCode(PythonCode):
     def add_backup_behaviour(self, agent: Agent) -> None:
         self.add_line('class BackupBehaviour(spade.behaviour.PeriodicBehaviour):')
         self.indent_right()
+        self.add_line('def __init__(self, start_at, period):')
+        self.indent_right()
+        self.add_line('super().__init__(start_at=start_at, period=period)')
+        self.add_line('self.httpx_client = httpx.AsyncClient(timeout=period)')
+        self.indent_left()
+        self.add_newline()
+        
         self.add_line('async def run(self):')
         self.indent_right()
         self.add_line('data = {')
         self.indent_right()
         self.add_line('"jid": str(self.agent.jid),')
-        for param_name in agent.param_names:
-            self.add_line(f'"{param_name}": self.agent.{param_name},')
+        self.add_line(f'"type": "{agent.name}",')
+        
+        self.add_line('"floats": {')
+        self.indent_right()
+        self.add_line('"msgRCount": self.agent.msgRCount,')
+        self.add_line('"msgSCount": self.agent.msgSCount,')
+        self.add_line('"connCount": self.agent.connCount,')
+        for float_param_name in agent.float_param_names:
+            self.add_line(f'"{float_param_name}": self.agent.{float_param_name},')
+        self.indent_left()
+        self.add_line('},')
+        
+        self.add_line('"enums": {')
+        self.indent_right()
+        for enum_param_name in agent.enums:
+            self.add_line(f'"{enum_param_name}": self.agent.{enum_param_name},')
+        self.indent_left()
+        self.add_line('},')
+        
+        self.add_line('"connections": {')
+        self.indent_right()
+        self.add_line('"connections": self.agent.connections,')
+        for connection_list_param_name in agent.connection_lists:
+            self.add_line(f'"{connection_list_param_name}": self.agent.{connection_list_param_name},')
+        self.indent_left()
+        self.add_line('},')
+        
+        self.add_line('"messages": {')
+        self.indent_right()
+        for message_list_param_name in agent.message_lists:
+            self.add_line(f'"{message_list_param_name}": self.agent.{message_list_param_name},')
+        self.indent_left()
+        self.add_line('}')
+        
         self.indent_left()
         self.add_line('}')
         self.add_line('if self.agent.logger: self.agent.logger.debug(f"[{self.agent.jid}] Sending backup data: {data}")')
         self.add_line('try:')
         self.indent_right()
-        self.add_line('async with httpx.AsyncClient() as client:')
-        self.indent_right()
-        self.add_line('await client.post(self.agent.backup_url, json=data)')
-        self.indent_left()
+        self.add_line('await self.http_client.post(self.agent.backup_url, json=data)')
         self.indent_left()
         self.add_line('except Exception as e:')
         self.indent_right()
-        self.add_line('if self.agent.logger: self.agent.logger.warn(f"[{self.agent.jid}] Backup error: {e}")')
+        self.add_line('if self.agent.logger: self.agent.logger.error(f"[{self.agent.jid}] Backup error type: {e.__class__}, additional info: {e}")')
         self.indent_left()
         self.indent_left()
         self.indent_left()
