@@ -8,14 +8,14 @@ import spade
 
 
 class average_user(spade.agent.Agent):
-    def __init__(self, jid, password, connections, backup_url = None, backup_period = 60, backup_delay = 0, logger = None, **kwargs):
+    def __init__(self, jid, password, backup_url = None, backup_period = 60, backup_delay = 0, logger = None, **kwargs):
         super().__init__(jid, password, verify_security=False)
-        if logger: logger.debug(f"[{jid}] Received parameters: jid: {jid}, password: {password}, connections: {connections}, backup_url: {backup_url}, backup_period: {backup_period}, backup_delay: {backup_delay}, kwargs: {kwargs}")
+        if logger: logger.debug(f"[{jid}] Received parameters: jid: {jid}, password: {password}, backup_url: {backup_url}, backup_period: {backup_period}, backup_delay: {backup_delay}, kwargs: {kwargs}")
         self.logger = logger
-        self.connections = connections
         self.backup_url = backup_url
         self.backup_period = backup_period
         self.backup_delay = backup_delay
+        self.connections = kwargs.get("connections", [])
         self.msgRCount = kwargs.get("msgRCount", 0)
         self.msgSCount = kwargs.get("msgSCount", 0)
         self.friends = kwargs.get("friends", [])
@@ -47,21 +47,33 @@ class average_user(spade.agent.Agent):
         if self.logger: self.logger.debug(f"[{self.jid}] Class dict after setup: {self.__dict__}")
     
     class BackupBehaviour(spade.behaviour.PeriodicBehaviour):
+        def __init__(self, start_at, period):
+            super().__init__(start_at=start_at, period=period)
+            self.httpx_client = httpx.AsyncClient(timeout=period)
+        
         async def run(self):
             data = {
                 "jid": str(self.agent.jid),
-                "connections": self.agent.connections,
-                "connCount": self.agent.connCount,
-                "msgRCount": self.agent.msgRCount,
-                "msgSCount": self.agent.msgSCount,
-                "friends": self.agent.friends,
+                "type": "average_user",
+                "floats": {
+                    "msgRCount": self.agent.msgRCount,
+                    "msgSCount": self.agent.msgSCount,
+                    "connCount": self.agent.connCount,
+                },
+                "enums": {
+                },
+                "connections": {
+                    "connections": self.agent.connections,
+                    "friends": self.agent.friends,
+                },
+                "messages": {
+                }
             }
             if self.agent.logger: self.agent.logger.debug(f"[{self.agent.jid}] Sending backup data: {data}")
             try:
-                async with httpx.AsyncClient() as client:
-                    await client.post(self.agent.backup_url, json=data)
+                await self.http_client.post(self.agent.backup_url, json=data)
             except Exception as e:
-                if self.agent.logger: self.agent.logger.warn(f"[{self.agent.jid}] Backup error: {e}")
+                if self.agent.logger: self.agent.logger.error(f"[{self.agent.jid}] Backup error type: {e.__class__}, additional info: {e}")
     
     class facebook_activity(spade.behaviour.PeriodicBehaviour):
         async def post_photos(self):
@@ -88,7 +100,7 @@ import numpy
 def generate_graph_structure(domain):
     _num_average_user = round(100 / 100 * 150)
     num_agents = _num_average_user
-    random_id = str(uuid.uuid4())[:4]
+    random_id = str(uuid.uuid4())[:5]
     jids = [f"{i}_{random_id}@{domain}" for i in range(num_agents)]
     agents = []
     next_agent_idx = 0
